[![license](https://img.shields.io/pypi/l/raking)](https://github.com/ihmeuw-msca/raking/blob/main/LICENSE)
[![version](https://img.shields.io/pypi/v/raking)](https://pypi.org/project/raking)
[![build](https://img.shields.io/github/actions/workflow/status/ihmeuw-msca/raking/build.yml?branch=main)](https://github.com/ihmeuw-msca/raking/actions)
[![docs](https://img.shields.io/badge/docs-here-green)](https://ihmeuw-msca.github.io/raking)
[![codecov](https://img.shields.io/codecov/c/github/ihmeuw-msca/raking)](https://codecov.io/gh/ihmeuw-msca/raking)
[![codacy](https://img.shields.io/codacy/grade/ae72a07785f5469eac234d1f6bdf555f)](https://app.codacy.com/gh/ihmeuw-msca/raking/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

# Raking

Raking is a well known method in survey sampling to adjust the cases in a contingency table to match the known marginal totals. This package has been developed to rake 1, 2 and 3D contingency tables.
